// ***************************************************************************
// Name:        3D-Wireframe (init file)
// Purpose:     shows wireframe 3d objects
// Copyright:   (C) 2003, 2004, 2005, 2007 Dominik Wagenfuehr <dominik.wagenfuehr@arcor.de>
// ***************************************************************************

/**
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "objects.h"

// **************************
// Application Class
// **************************

class ImageApp : public wxApp {                  // application class                                        
  virtual bool OnInit() {                          // init (create frame etc.)
    ImageFrame *frame = new ImageFrame("3D Wireframe", wxPoint(-1,-1), wxSize(648, 377));

    frame->SetStandPoint(Vector(7,20,50));		// position
    frame->SetViewPoint(Vector(0.2,-0.4,-1));    // view direction

    Vertex v;
    Model room, window, door, bed, closet, couch, ctable, keyboard, shelves, desk1, desk2, desk3;
    
    // Begin Room
    v=Vector(0,0,0);
    v.AddEdge(Vector(52.2,0,0));
    v.AddEdge(Vector(0,0,38.1));
    v.AddEdge(Vector(0,24,0));
    room.AddVertex(v);
    v=Vector(0,24,38.1);
    v.AddEdge(Vector(0,24,0));
    v.AddEdge(Vector(0,0,38.1));
    v.AddEdge(Vector(11,24,38.1));
    room.AddVertex(v);
    v=Vector(52.2,24,0);
    v.AddEdge(Vector(0,24,0));
    v.AddEdge(Vector(52.2,0,0));
    v.AddEdge(Vector(52.2,24,30.9));
    room.AddVertex(v);
    v=Vector(52.2,0,30.9);
    v.AddEdge(Vector(52.2,24,30.9));
    v.AddEdge(Vector(52.2,0,0));
    v.AddEdge(Vector(11,0,30.9));
    room.AddVertex(v);
    v=Vector(11,24,30.9);
    v.AddEdge(Vector(52.2,24,30.9));
    v.AddEdge(Vector(11,24,38.1));
    v.AddEdge(Vector(11,0,30.9));
    room.AddVertex(v);
    v=Vector(11,0,38.1);
    v.AddEdge(Vector(11,24,38.1));
    v.AddEdge(Vector(11,0,30.9));
    v.AddEdge(Vector(0,0,38.1));
    room.AddVertex(v);
    // End Room
  
    // Begin Window
    v=Vector(0,0,0);
    v.AddEdge(Vector(19.6,0,0));
    v.AddEdge(Vector(0,12,0));
    window.AddVertex(v);
    v=Vector(19.6,12,0);
    v.AddEdge(Vector(19.6,0,0));
    v.AddEdge(Vector(0,12,0));
    window.AddVertex(v);
    // End Window
    window.Translate(Vector(16.7, 9.5, 0)); // Move Window

    // Begin Door
    v=Vector(0,0,0);
    v.AddEdge(Vector(9.3,0,0));
    v.AddEdge(Vector(0,20,0));
    door.AddVertex(v);
    v=Vector(9.3,20,0);
    v.AddEdge(Vector(9.3,0,0));
    v.AddEdge(Vector(0,20,0));
    door.AddVertex(v);
    // End Door
    door.Translate(Vector(0.9, 0, 38.1)); // Move Door

    bed=bed.CreateQuader(21.7,3.5,15.5);
    bed.Translate(Vector(52.2-21.7, 0, 30.9-15.5));
    couch=couch.CreateQuader(20,7.3,8.7);
    couch.Translate(Vector(15, 0, 0));
    ctable=ctable.CreateQuader(11.6,4.7,6.5);
    ctable.Translate(Vector(15, 0, 9));
    closet=closet.CreateQuader(6,19,10);
    closet.Translate(Vector(0, 0, 8));
    keyboard=keyboard.CreateQuader(11.4,8.7,4.5);
    keyboard.Translate(Vector(52.2-11.4-21.7, 0, 30.9-4.5));
    shelves=shelves.CreateQuader(5.1,16.7,8);
    shelves.Translate(Vector(0, 0, 0));
    desk1=desk1.CreateQuader(13, 7.3,5.7);
    desk2=desk2.CreateQuader(4, 7.3, 15-5.7);
    desk2.Translate(Vector(0, 0, 5.7));
    desk3=desk3.CreateQuader(13,12.6-7.3,2.5);
    desk3.Translate(Vector(0, 7.3, 0));
    desk1.Rotate(-90, frame->Ey);
    desk2.Rotate(-90, frame->Ey);
    desk3.Rotate(-90, frame->Ey);
    desk1.Translate(Vector(52.2, 0, 0));
    desk2.Translate(Vector(52.2, 0, 0));
    desk3.Translate(Vector(52.2, 0, 0));

    // Creating scene
    frame->AddModel(room);         // Add Room
    frame->AddModel(window);         // Add Window
    frame->AddModel(door);         // Add Door
    frame->AddModel(bed);         // Add Bed
    frame->AddModel(couch);         // Add couch
    frame->AddModel(ctable);         // Add couch table
    frame->AddModel(closet);         // Add closet
    frame->AddModel(keyboard);         // Add keyboard
    frame->AddModel(shelves);         // Add shelves
    frame->AddModel(desk1);         // Add desk1
    frame->AddModel(desk2);         // Add desk2
    frame->AddModel(desk3);         // Add desk3
 
    frame->Show();
    return (true);
  }
};

IMPLEMENT_APP(ImageApp);


